# coding=UTF-8
from .verify import setToken
from .runner import Runner, Result, EMTResult, PowerFlowResult
from .model import Model, ModelRevision, ModelTopology
from .project import Project
from .utils import MatlabDataEncoder, DateTimeEncode
from . import function

__all__ = [
    'setToken', 'Model', 'ModelRevision', 'ModelTopology', 'Runner', 'Result',
    'PowerFlowResult', 'EMTResult', 'MatlabDataEncoder', 'DateTimeEncode',
    'function', 'Project'
]
__version__ = '3.0.1'



# coding=UTF-8

import json
import requests
import os
from collections import OrderedDict


def request(method, uri, baseUrl=None, params={}, token=None, **kwargs):
    if baseUrl == None:
        baseUrl = os.environ.get('CLOUDPSS_API_URL', 'https://cloudpss.net/')
    url = requests.compat.urljoin(baseUrl, uri)
    token = os.environ.get('CLOUDPSS_TOKEN', None)
    if token:
        headers = {
            'Authorization': 'Bearer ' + token,
            'Content-Type': 'application/json; charset=utf-8'
        }
    else:
        raise Exception('token undefined')
    r = requests.request(method, url, params=params, headers=headers, **kwargs)

    if (uri.startswith('/graphql')):
        if 'X-Cloudpss-Version' not in r.headers:
            raise Exception(
                '当前SDK版本（ver 3.X.X）与服务器版本（3.0.0 以下）不兼容，请更换服务器地址或更换SDK版本。')
        if r.headers['X-Cloudpss-Version'] != '3':
            raise Exception('当前SDK版本（ver 3.X.X）与服务器版本（ver ' +
                            r.headers['X-Cloudpss-Version'] +
                            '.X.X）不兼容，请更换服务器地址或更换SDK版本。')

    try:
        r.raise_for_status()
    except Exception as e:
        raise Exception(r.text)
    return r



from .job import Job
from ..utils import request
from .function import Function
import json

__all__ = ['Function', 'Job']


def createJob():
    pass


def currentJob():
    return Job.current()
    pass


def fetch(rid):
    """
        获取函数
    """
    query = """
        query ($rid:ResourceId!) {
                
            function(rid:$rid) {
                rid,
                documentation
                parameters
                implementType
                implement
                configs
                context
                name
                description
                type
                owner
                key
                executor
            }
        }
    """
    payload = {
        'query': query,
        'variables': {
            'rid': rid,
        }
    }
    r = request('POST', 'graphql', data=json.dumps(payload))
    data = json.loads(r.text)
    return Function(data['data']['function'])


def fetchMany(name=None, pageSize=10, pageOffset=0):
    pass
